@@ -34,7 +34,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGES.
  *
- * $Id: if_ath_pci.c 1988 2007-01-22 03:07:30Z proski $
+ * $Id: if_ath_pci.c 3311 2008-01-30 20:56:11Z proski $
  */
 #include "opt_ah.h"
 
@@ -207,7 +207,7 @@ ath_pci_probe(struct pci_dev *pdev, const struct pci_device_id *id)
 
 	pci_set_drvdata(pdev, dev);
 
-	if (request_irq(dev->irq, ath_intr, SA_SHIRQ, dev->name, dev)) {
+	if (request_irq(pdev->irq, ath_intr, IRQF_SHARED, dev->name, dev)) {
 		printk(KERN_WARNING "%s: request_irq failed\n", dev->name);
 		goto bad3;
 	}
@@ -325,7 +325,7 @@ ath_pci_resume(struct pci_dev *pdev)
 
 MODULE_DEVICE_TABLE(pci, ath_pci_id_table);
 
-static struct pci_driver ath_pci_drv_id = {
+static struct pci_driver ath_pci_driver = {
 	.name		= "ath_pci",
 	.id_table	= ath_pci_id_table,
 	.probe		= ath_pci_probe,
@@ -340,9 +340,8 @@ static struct pci_driver ath_pci_drv_id = {
 /*
  * Module glue.
  */
-#include "version.h"
 #include "release.h"
-static char *version = ATH_PCI_VERSION " (" RELEASE_VERSION ")";
+static char *version = RELEASE_VERSION;
 static char *dev_info = "ath_pci";
 
 #include <linux/ethtool.h>
@@ -381,7 +380,7 @@ init_ath_pci(void)
 {
 	printk(KERN_INFO "%s: %s\n", dev_info, version);
 
-	if (pci_register_driver(&ath_pci_drv_id) < 0) {
+	if (pci_register_driver(&ath_pci_driver) < 0) {
 		printk("ath_pci: No devices found, driver not installed.\n");
 		return (-ENODEV);
 	}
@@ -394,7 +393,7 @@ static void __exit
 exit_ath_pci(void)
 {
 	ath_sysctl_unregister();
-	pci_unregister_driver(&ath_pci_drv_id);
+	pci_unregister_driver(&ath_pci_driver);
 
 	printk(KERN_INFO "%s: driver unloaded\n", dev_info);
 }
